@@ -25,6 +25,18 @@ def getSearchUrl(key):
 def clearUrl(url):
 	return url.split('?')[0]
 
+def getSingleCount(card):
+	return (int(card['reposts_count']) + 
+			int(card['comments_count']) + 
+			int(card['attitudes_count']))
+
+def getCount(card):
+	card = card.get('mblog', card)
+	count = getSingleCount(card)
+	if 'retweeted_status' in card:
+		count += getSingleCount(card['retweeted_status']) / 3
+	return count
+
 def getTextHash(card):
 	result = []
 	for x in card.get('text', ''):
@@ -40,15 +52,27 @@ def getHash(card):
 		return getTextHash(card.get('retweeted_status'))
 	return getTextHash(card)
 
-def search(key, force_cache=False, sleep=0):
-	url = getSearchUrl(key)
-	content = cached_url.get(url, force_cache=force_cache, 
-		sleep = sleep)
-	content = yaml.load(content, Loader=yaml.FullLoader)
+def sortedResult(result):
+	to_sort = []
+	for url, card in result.items():
+		to_sort.append((getCount(card), (url, card)))
+	to_sort.sort(reverse=True)
+	return [item[1] for item in to_sort]
+
+def getResultDict(content):
 	result = {}
 	for card in content['data']['cards']:
 		if 'scheme' in card:
 			url = clearUrl(card['scheme'])
 			if '/status/' in url:
 				result[url] = card
-	return result
\ No newline at end of file
+	return result
+
+# result is approximately sorted by like
+def search(key, force_cache=False, sleep=0): 
+	url = getSearchUrl(key)
+	content = cached_url.get(url, force_cache=force_cache, 
+		sleep = sleep)
+	content = yaml.load(content, Loader=yaml.FullLoader)
+	result = getResultDict(content)
+	return sortedResult(result)
